@@ -122,8 +122,8 @@ class MelodicIntervalTeacher(Teacher):
                     # we, find the interval that is closest to the range
                     # of notes the user want. This mean that the questions
                     # are not necessarily that random.
-                    low = mpd.MusicalPitch(L)
-                    high = mpd.MusicalPitch(H)
+                    low = mpd.MusicalPitch.new_from_int(L)
+                    high = mpd.MusicalPitch.new_from_int(H)
                     off = 1000
                     best = None
                     for interval in self.get_list('ask_for_intervals_%i'%x):
@@ -240,6 +240,34 @@ You really should reastart the program now.""")
                 self.set_string('lessonfile', lessonfile)
         for key, val in config.iteritems():
             self.set_string(key, val)
+    def check_askfor(self):
+        """
+        This function will check if the lesson file we have now is the same
+        as the lesson we had last time we used the exercise. If so, the
+        same questions will be activated. If not, all questions in the
+        file will be asked for.
+        """
+        if self.m_P.header.questions_selectable:
+            same_file = self.get_list("ask_for_names_fn") \
+                 == [self.get_string("lessoncollection"),
+                     self.get_string("lessonfile")]
+            if (not self.get_list('ask_for_names')) or (not same_file):
+                self.block_watch('ask_for_names')
+                self.set_list('ask_for_names', range(0, len(self.m_P.get_unique_cnames())))
+                self.set_list("ask_for_names_fn",
+                          [self.get_string("lessoncollection"),
+                           self.get_string("lessonfile")])
+                self.unblock_watch('ask_for_names')
+            for question in self.m_P.m_questions:
+                question['active'] = 0
+            for idx in self.get_list('ask_for_names'):
+                if idx >= len(self.m_P.get_unique_cnames()):
+                    # if we get,  .solfegerc has some bad data.
+                    break
+                cname = self.m_P.get_unique_cnames()[idx]
+                for question in self.m_P.m_questions:
+                    if question.get_cname() == cname:
+                        question['active'] = 1
 
 class Gui(gtk.VBox, cfg.ConfigUtils):
     """Important members:
@@ -437,8 +465,7 @@ class LessonbasedGui(Gui):
         label.show()
         hbox.pack_start(label, False)
         hbox.set_spacing(6)
-        self.g_random_transpose = gtk.Entry()
-        self.g_random_transpose.set_editable(False)
+        self.g_random_transpose = gtk.Label()
         self.g_random_transpose.show()
         hbox.pack_start(self.g_random_transpose)
 
