@@ -232,7 +232,14 @@ It is also possible that the OS sound setup is incorrect.
         elif protocol == 'http':
             webbrowser.open_new(href)
         elif protocol == 'mailto':
-            os.system(self.get_string("config/mua") % href)
+            if self.get_string("config/mua"):
+                try:
+                    cmdline = self.get_string("config/mua") % href
+                except TypeError:
+                    cmdline = "%s %s" % (self.get_string("config/mua"), href)
+                os.system(cmdline)
+            else:
+                self.m_ui.dialog_ok(_("You have not selected email program. You can do so in the preferences window."))
         else:
             print "unknown link type", protocol
     def handle_solfege_href(self, href, action, fn, anchor, lessoncollection,
