@@ -294,7 +294,7 @@ class Gui(abstract.LessonbasedGui):
             else:
                 self.g_flashbar.flash(_("Wrong"))
         elif self.m_t.q_status in (const.QSTATUS_TYPE_SOLVED, const.QSTATUS_VOICING_WRONG):
-            self.g_flashbar.flash(_("Type is already solved, now specify voicing"))
+            self.g_flashbar.flash(_("Type is already solved, now specify voicing."))
     def on_notebutton_clicked(self, btn, n, user_notename):
         newb = gtk.Button(user_notename)
         newb.show()
@@ -346,6 +346,10 @@ class Gui(abstract.LessonbasedGui):
         for c in self.g_chordtype_box.get_children():
             c.set_sensitive(c.get_data('chordtype')==t)
     def on_start_practise(self):
+        self.g_flashbar.require_size([
+            _("You have to solve this question first."),
+            _("Type is already solved, now specify voicing."),
+        ])
         self.g_new.grab_focus()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New chord' to begin.")))
