@@ -265,8 +265,8 @@ class Lexer:
 class Dataparser:
     def __init__(self, globals={}, function_dict={}, gd=[]):
         self.gd = gd
-        self.globals = globals
-        self.functions = function_dict
+        self.globals = globals.copy()
+        self.functions = function_dict.copy()
         self.header = {}
         self.questions = []
         self.context = self.globals
