@@ -20,6 +20,7 @@ import gnome
 import gobject
 import soundcard
 import cfg
+import widgets
 
 #  Prefixes used in this module:
 #  t  pack into a table, the first five parameters are table, x1, x2, y1, y2
@@ -177,10 +178,23 @@ class FlashBar(gtk.Frame):
         #FIXME different gtk themes can make these values wrong
         self.set_size_request(-1, 40)
         self.__stack = []
-        import widgets
         self.__label = widgets.HarmonicProgressionLabel('')
         self.add(self.__label)
         self.__timeout = None
+    def require_size(self, stringlist):
+        """
+        stringlist is a list of the strings believed to be widest.
+        require_size will make sure that the flashbar is at least large enough to
+        show all the strings in stringlist.
+        """
+        mx, my = 0, 0
+        for s in stringlist:
+            self.__label.set_text(s)
+            x, y =  self.__label.size_request()
+            mx = max(x, mx)
+            my = max(y, my)
+        self.__label.set_text("")
+        self.__label.set_size_request(mx, my)
     def flash(self, txt):
         """Display a message that is automatically removed after some time.
         If we flash a new message before the old flashed message are removed,
