@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,20 +15,30 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from __future__ import division
+
 __exercise_data__ = {
     'exercise_name': 'harmonic-interval',
-    'menu_path': '%s/%s' % (_("_Intervals"), _("_Harmonic interval")),
     'stock-icon': 'solfege-harmonic-interval',
-    'toolbar': 2,
+    'menupath': '/Menubar/FileMenu/IntervalsMenu',
+    'name': _('_Harmonic interval'),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
+import os
+import pickle
+import time
 import gtk, gnome, gobject
 import gu, widgets, inputwidgets
 import soundcard, mpd
 import abstract, const, utils
 import statistics, statisticsviewer
+import htmlwidget
+import cfg
+import random
+import gethomedir
+import intervaltest
 
 class Teacher(abstract.Teacher):
     exercise_data = __exercise_data__
@@ -139,13 +149,14 @@ class Teacher(abstract.Teacher):
         m.note(4, 1, high_tone, instr_high_vel)
         soundcard.synth.play_track(m)
 
-
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
         abstract.IntervalGui.__init__(self, teacher, window)
+        self.g_test_stat_dlg = None
         ################
         # practice_box #
         ################
+        self.g_merge_id = None
         self.g_repeat_melodic = gu.bButton(self.action_area,
             _("Repeat _melodic"), self.repeat_melodic)
 
@@ -162,6 +173,10 @@ class Gui(abstract.IntervalGui):
         self.g_interval_selector = widgets.IntervalCheckBox(
                                           self.m_exname, 'intervals')
 
+        def _ff(var):
+            self.on_end_practise()
+            self.on_start_practise()
+        self.add_watch('intervals', _ff)
         self.g_interval_selector.set_border_width(gnome.ui.PAD)
         frame.add(self.g_interval_selector)
         #------we need some space
@@ -188,16 +203,12 @@ class Gui(abstract.IntervalGui):
         hbox.set_spacing(gnome.ui.PAD_SMALL)
         gu.bLabel(hbox, _("Input interface:"), False)
 
-        optionmenu = gtk.OptionMenu()
-        menu = gtk.Menu()
+        combo = gtk.combo_box_new_text()
         for i in range(len(inputwidgets.inputwidget_names)):
-            item = gtk.MenuItem(inputwidgets.inputwidget_names[i])
-            menu.add(item)
-            item.connect('activate',
-                         lambda widget, i=i: self.use_inputwidget(i))
-        optionmenu.set_menu(menu)
-        optionmenu.set_history(self.get_int('inputwidget'))
-        hbox.pack_start(optionmenu, False)
+            combo.append_text(inputwidgets.inputwidget_names[i])
+        combo.set_active(self.get_int('inputwidget'))
+        combo.connect('changed', lambda w: self.use_inputwidget(w.get_active()))
+        hbox.pack_start(combo, False)
 
         self.g_disable_unused_buttons = gu.nCheckButton(self.m_exname,
                     'disable_unused_intervals', _("_Disable unused buttons"))
@@ -213,7 +224,26 @@ class Gui(abstract.IntervalGui):
         ##############
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
                                    _("Harmonic interval"))
+        ########
+        # Test #
+        ########
+        self.g_action_group = gtk.ActionGroup('HarmonicIntervalActions')
+        self.g_action_group.add_actions([
+            ('ExerciseMenu', None, _('_Exercise')),
+            ('TestEx', None, _('_Run test'), None, None, self.run_test),
+            ('HarmTestStatistics', None, _('_Test statistics'), None, None,
+             self.show_test_statistics),
+            ])
+        self.g_win.g_ui_manager.insert_action_group(self.g_action_group, 0)
         self.select_inputwidget()
+    def run_test(self, *v):
+        tw = intervaltest.HarmonicIntervalTestDialog()
+        tw.set_modal(True)
+        tw.show_all()
+        gtk.main()
+        self.g_test_stat_dlg = intervaltest.TestStatisticsDialog(self, _("Harmonic interval test results"), tw.m_test.get_test_results_dict(), False)
+        self.g_test_stat_dlg.show_all()
+        tw.destroy()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
             self.g_flashbar.push(_("The answer is: %s")
@@ -302,10 +332,20 @@ class Gui(abstract.IntervalGui):
         self.g_input.grab_focus_first_sensitive_button()
     def on_start_practise(self):
         self.m_t.m_statistics.reset_session()
+        self.g_action_group.set_sensitive(True)
         self.g_new_interval.grab_focus()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New interval' to begin.")))
+        self.g_merge_id = self.g_win.g_ui_manager.add_ui_from_string("""
+<menubar name='Menubar'>
+  <menu action='ExerciseMenu'>
+    <menuitem action='TestEx'/>
+    <menuitem action='HarmTestStatistics'/>
+  </menu>
+</menubar>""")
     def on_end_practise(self):
+        if self.g_merge_id:
+            self.g_win.g_ui_manager.remove_ui(self.g_merge_id)
         self.m_t.end_practise()
         self.g_new_interval.set_sensitive(True)
         self.g_repeat.set_sensitive(False)
