@@ -108,6 +108,10 @@ class Gui(abstract.LessonbasedGui):
         self.practise_box.set_spacing(gnome.ui.PAD)
 
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
+        self.g_play_music = gu.bButton(self.action_area, _("Play music"),
+            lambda w: self.m_t.m_P.play_question())
+        self.g_display_music = gu.bButton(self.action_area, _("Display music"),
+            self.show_music)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
                                    self.repeat_question)
         self.g_repeat_arpeggio = gu.bButton(self.action_area,
@@ -118,7 +122,7 @@ class Gui(abstract.LessonbasedGui):
               _("_Give up"), self.give_up)
         self.g_give_up.set_sensitive(False)
 
-        self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_answer)
+        self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_music)
         self.g_show.set_sensitive(False)
         self.practise_box.show_all()
         ##############
@@ -146,16 +150,31 @@ class Gui(abstract.LessonbasedGui):
                                    _("Identify by name"))
 
         self.update_gui_after_lessonfile_change()
-    def show_answer(self, widget=None):
+        def _f(varname):
+            self.on_end_practise()
+            self.on_start_practise()
+        self.add_watch('ask_for_names', _f)
+    def show_music(self, widget=None):
         """
         Show the answer in the g_music_displayer if we have one, if not
         use a new window.
         """
+        if 'vmusic' in self.m_t.m_P.get_question():
+            varname = 'vmusic'
+        else:
+            varname = 'music'
         if self.m_t.m_P.header.have_music_displayer:
             fontsize = self.get_int('config/feta_font_size=20')
-            self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
+            self.g_music_displayer.display(self.m_t.m_P.get_music(varname), fontsize)
         else:
-            self.g_win.display_in_musicviewer(self.m_t.m_P.get_music())
+            self.g_win.display_in_musicviewer(self.m_t.m_P.get_music(varname))
+    def display_music(self, varname):
+        """
+        Display the music in the variable named by varname from
+        the currently selected question.
+        """
+        fontsize = self.get_int('config/feta_font_size=20')
+        self.g_music_displayer.display(self.m_t.m_P.get_music(varname), fontsize)
     def update_answer_buttons(self):
         if self.m_t.m_P:
             self.g_bb.initialize(self.m_t.m_P.header.fillnum,
@@ -183,6 +202,8 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat_slowly.set_sensitive(False)
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_show.set_sensitive(False)
+        self.g_display_music.set_sensitive(False)
+        self.g_play_music.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
         if self.m_t.m_P:
@@ -197,27 +218,25 @@ class Gui(abstract.LessonbasedGui):
                 self.g_repeat_slowly.show()
             else:
                 self.g_repeat_slowly.hide()
+            if self.m_t.m_P.header.at_question_start == 'show':
+                self.g_play_music.show()
+                self.g_repeat.hide()
+            else:
+                self.g_play_music.hide()
+                self.g_repeat.show()
+            if self.m_t.m_P.header.at_question_start == 'play':
+                self.g_display_music.show()
+            else:
+                self.g_display_music.hide()
             if self.m_t.m_P.header.have_music_displayer:
                 self.g_music_displayer.show()
+                self.g_music_displayer.clear()
                 self.g_show.hide()
             else:
                 self.g_music_displayer.hide()
                 self.g_show.show()
             if self.m_t.m_P.header.questions_selectable:
-                if not self.get_list('ask_for_names'):
-                    self.block_watch('ask_for_names')
-                    self.set_list('ask_for_names', range(0, len(self.m_t.m_P.get_unique_cnames())))
-                    self.unblock_watch('ask_for_names')
-                for question in self.m_t.m_P.m_questions:
-                    question['active'] = 0
-                for idx in self.get_list('ask_for_names'):
-                    if idx >= len(self.m_t.m_P.get_unique_cnames()):
-                        # if we get,  .solfegerc has some bad data.
-                        break
-                    cname = self.m_t.m_P.get_unique_cnames()[idx]
-                    for question in self.m_t.m_P.m_questions:
-                        if question.get_cname() == cname:
-                            question['active'] = 1
+                self.m_t.check_askfor()
         else:
             self.g_new.set_sensitive(False)
         self.update_select_question_buttons()
@@ -231,7 +250,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_new.grab_focus()
             self.g_give_up.set_sensitive(False)
             if self.m_t.m_P.header.have_music_displayer:
-                self.show_answer()
+                self.show_music()
     def on_click(self, button, event=None):
         if not event:
             self.on_left_click(button)
@@ -278,7 +297,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_show.set_sensitive(True)
                 self.g_give_up.set_sensitive(False)
                 if self.m_t.m_P.header.have_music_displayer:
-                    self.show_answer()
+                    self.show_music()
             else:
                 self.g_flashbar.flash(_("Wrong"))
                 if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
@@ -301,10 +320,24 @@ class Gui(abstract.LessonbasedGui):
         try:
             g = self.m_t.new_question()
             if g == self.m_t.OK:
-                self.m_t.m_P.play_question()
+                if self.m_t.m_P.header.at_question_start == 'show':
+                    self.show_music()
+                elif self.m_t.m_P.header.at_question_start == 'play':
+                    self.m_t.m_P.play_question()
+                    if 'cuemusic' in self.m_t.m_P.get_question():
+                        self.display_music('cuemusic')
+                else:
+                    self.m_t.m_P.play_question()
+                    if 'show' in self.m_t.m_P.header.at_question_start \
+                        and 'play' in self.m_t.m_P.header.at_question_start:
+                        self.show_music()
+                    elif 'cuemusic' in self.m_t.m_P.get_question():
+                        self.display_music('cuemusic')
                 self.g_repeat.set_sensitive(True)
                 self.g_repeat_slowly.set_sensitive(True)
                 self.g_repeat_arpeggio.set_sensitive(True)
+                self.g_display_music.set_sensitive(True)
+                self.g_play_music.set_sensitive(True)
                 self.g_new.set_sensitive(
                     not self.get_bool('config/picky_on_new_question'))
                 self.g_bb.grab_focus_first_button()
@@ -332,6 +365,14 @@ class Gui(abstract.LessonbasedGui):
         self.g_bb.grab_focus_first_button()
         self.m_t.m_P.play_question_slowly()
     def on_start_practise(self):
+        self.g_flashbar.require_size([
+            _("Right click is not allowed for this lesson file."),
+            _("You should try to guess before right-clicking."),
+            _("You should try to guess before right-clicking."),
+            _("Correct, but you have already solved this question"),
+            _("Wrong, but you have already solved this question"),
+            _("You have to select some questions to practise."),
+        ])
         self.g_new.grab_focus()
         self.m_t.m_statistics.reset_session()
         self.g_music_displayer.clear()
