@@ -108,6 +108,8 @@ predef = {'dictation': 'dictation',
           'accidentals': 'accidentals',
           'key': 'key',
           'semitones': 'semitones',
+          'play': 'play',
+          'show': 'show',
           'tempo': (60, 4)}
 
 lessonfile_functions = {
@@ -139,8 +141,7 @@ class _Header:
                            ('questions_selectable', False),
                            ('have_repeat_slowly_button', False),
                            ('have_repeat_arpeggio_button', False),
-                           ('have_play_music_button', False),
-                           ('have_display_music_button', False),
+                           ('at_question_start', []),
                            ('have_music_displayer', False),
                            ('enable_right_click', True),
                            ):
@@ -431,17 +432,7 @@ class LessonfileCommon(object):
                r'\addvoice\transpose %s' % self.m_transpose.get_octave_notename())
             return s
         return question[varname].m_musicdata
-    def get_music_as_notename_list(self, varname):
-        """
-        Return a list of notenames from the variabale VARNAME in the
-        currently selected question. The notes are transposed if
-        header.random_transpose is set.
-
-        Assert m_musictype in ('chord', 'satb')
-        """
-        assert self._idx is not None
-        music = self.get_question()[varname]
-        assert music.m_musictype in ('chord', 'satb')
+    def music_to_notename_list(self, music):
         if music.m_musictype == 'chord':
             if not self.header.random_transpose:
                 return music.m_musicdata.split()
@@ -457,6 +448,17 @@ class LessonfileCommon(object):
             return v
         else:
             raise LessonfileException("get_music_as_notename_list cannot handle m_musictype==%s" % music.m_musictype)
+ 
+    def get_music_as_notename_list(self, varname):
+        """
+        Return a list of notenames from the variabale VARNAME in the
+        currently selected question. The notes are transposed if
+        header.random_transpose is set.
+
+        Assert m_musictype in ('chord', 'satb')
+        """
+        assert self._idx is not None
+        return self.music_to_notename_list(self.get_question()[varname])
     def get_music_as_notename_string(self, varname):
         """
         Return a string with notenames representing the question currently
@@ -516,7 +518,7 @@ class LessonfileCommon(object):
             assert len(instrument) == 6
             track = soundcard.Track()
             track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
-            nlist = self.get_music_as_notename_list(varname)
+            nlist = self.music_to_notename_list(question[varname])
             # set patches
             track.set_patch(0, instrument[0])
             for x in range(1, len(nlist)-1):
@@ -716,10 +718,21 @@ class IdByNameLessonfile(LessonfileCommon):
         self.parse_file(filename)
     def parse_file(self, filename):
         super(IdByNameLessonfile, self).parse_file(filename)
-        for question in self.m_questions:
+        # Some variables does only make sense if we have a music displayer
+        if self.header.at_question_start:
+            self.header.have_music_displayer = True
+        # Also, if some questions has cuemusic, then we need the displayer
+        if [q for q in self.m_questions if 'cuemusic' in q]:
+            self.m_header.have_music_displayer = True
+        # Delete questions that does not have a name
+        q = self.m_questions
+        self.m_questions = []
+        for question in q:
             if 'name' not in question:
                 print >> sys.stderr, "IdByNameLessonfile.parse_file: discarding question in the lessonfile '%s'\nbecause of missing 'name' variable" % filename
                 continue
+            else:
+                self.m_questions.append(question)
 
 class SingAnswerLessonfile(LessonfileCommon):
     def __init__(self, filename, teacher):
@@ -821,22 +834,21 @@ class LessonFileManager:
         for collection in self.m_db.itervalues():
             for content in collection:
                 collection[content].sort()
-        self.m_htmldoc = """<html><body><p>This list is updated each time
-                you start Solfege. As you can see, Solfege need more
-                lessonfiles. <a href="lessonfiles.html">Write one!</a>"""
+        self.m_htmldoc = """<html></head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></head><body><p>%s</p>""" % _("This page lists all the lesson files that Solfege can find. You can click on the links to start practising.")
         if self.m_invalid_files:
-            self.m_htmldoc += "<h1>Files we failed to parse</h1><ul>"
+            self.m_htmldoc += "<h1>%s</h1><ul>" % _("Files we failed to parse")
             for collection, filename in self.m_invalid_files:
-                self.m_htmldoc += "<li>%(filename)s in collection %(collection)s</li>" % {'collection': collection, 'filename': filename}
+                self.m_htmldoc += "<li>%s</li>" % (_("%(filename)s in collection %(collection)s") % {'collection': collection, 'filename': filename})
             self.m_htmldoc += "</ul>"
         for collection in self.m_db:
-            self.m_htmldoc = self.m_htmldoc + "<h1>collection: %s</h1>" % collection
+            self.m_htmldoc = self.m_htmldoc + "<h1>%s: %s</h1>" % (_("Lesson collection"), collection)
             for use in self.m_db[collection]:
                 self.m_htmldoc = self.m_htmldoc + "<h2>%s</h2><p>" % use
                 for d in self.m_db[collection][use]:
                     fn = d['filename']
                     self.m_htmldoc = self.m_htmldoc + \
-                      "<a href=\"solfege:practise/%s/%s/%s\">%s</a>\n" % (use, collection, fn, fn)
+                      "<br><a href=\"solfege:practise/%(use)s/%(collection)s/%(fn)s\">%(fn)s</a>: %(title)s\n" % {'use':use, 'collection': collection,
+                        'fn': fn, 'title': d['title']}
                 self.m_htmldoc += "</p>"
         self.m_htmldoc = self.m_htmldoc + "</body></html>"
     def get_collections(self):
