@@ -26,6 +26,8 @@ __builtin__.__exdata__ = []
 import sys
 import os
 import time
+import urllib
+
 import runtime
 
 import configureoutput
@@ -299,16 +301,12 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           ('HelpMenu', None, _('_Help')),
           ('HelpHelp', 'gtk-help', _('_Help on current exercise'), 'F1', None,
             lambda o: self.m_app.please_help_me()),
-          ('HelpWelcome', None, _('_Welcome'), None, None,
-            lambda o: self.m_app.handle_href('welcome.html')),
           ('HelpIndex', None, _('_All help files'), None, None,
             lambda o: self.m_app.handle_href('toc.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
             None, lambda o: self.m_app.handle_href('solfege:all-lessonfiles')),
           ('HelpCopyright', None, _('_Copyright notice'), None, None,
             lambda o: self.m_app.handle_href('copyright.html')),
-          ('HelpCredits', None, _('C_redits'), None, None,
-            lambda o: self.m_app.handle_href('AUTHORS.html')),
           ('HelpOnline', None, _('_Mailinglists, web page etc.'), None, None,
             lambda o: self.m_app.handle_href('online-resources.html')),
           ('HelpReportingBugs', None, _('Reporting _bugs'), None, None,
@@ -323,6 +321,8 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset()),
           ('BrowserGoBack', 'gtk-go-back', None, None, None, self.history_back),
           ('BrowserGoForward', 'gtk-go-forward', None, None, None, self.history_forward),
+          ('ShowBugReports', None, _('See your bug reports'), None, None,
+            self.show_bug_reports),
         ])
         self.g_ui_manager = gtk.UIManager()
         self.g_ui_manager.insert_action_group(self.g_action_group, 1)
@@ -391,6 +391,15 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         #FIXME not using GnomeApp.add_toolbar
         #self.add_toolbar(self.g_ui_manager.get_widget('/Toolbar'),
         #  'toolbaren', 'normal', 'top', 1, 0,0)
+    def dialog_ok(self, text):
+        """"
+        Return the gtk.RESPONSE_XXXX returned by .run()
+        """
+        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
+                gtk.BUTTONS_OK, text)
+        ret = m.run()
+        m.destroy()
+        return ret
     def dialog_yesno(self, text):
         """Return True if the answer is yes, False if the answer is no.
         """
@@ -399,6 +408,30 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         ret = m.run()
         m.destroy()
         return ret == gtk.RESPONSE_YES
+    def show_bug_reports(self, *v):
+        m = gtk.Dialog(_("Question"), self, 0)
+        m.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
+        m.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
+        vbox = gtk.VBox()
+        m.vbox.pack_start(vbox, False)
+        vbox.set_spacing(18)
+        vbox.set_border_width(12)
+        l = gtk.Label(_("Please enter the email used when you submitted the bugs:"))
+        vbox.pack_start(l, False)
+        self.g_email = gtk.Entry()
+        m.action_area.get_children()[0].grab_default()
+        self.g_email.set_activates_default(True)
+        vbox.pack_start(self.g_email, False)
+        m.show_all()
+        ret = m.run()
+        m.destroy()
+        if ret == gtk.RESPONSE_OK:
+            params = urllib.urlencode({
+                    'pagename': 'SITS-Incoming/SearchBugs',
+                    'q': 'SITS-Incoming/"Submitter: %s"' % utils.mangle_email(self.g_email.get_text()),
+                })
+            import webbrowser
+            webbrowser.open_new("http://www.solfege.org?%s" % params)
     def display_exception_message(self, exception, err_file=None):
         """Call this function only inside an except clause."""
         if err_file:
@@ -439,8 +472,14 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                   'Giovanni Chierico %s' % _("(some lessonfiles)"),
                   'Michael Becker %s' % _("(some lessonfiles)"),
                   'Joe Lee %s' % _("(sound code for the MS Windows port)"),
+                  'Steve Lee %s' % _("ported winmidi.c to gcc)"),
+                  'Thibaus Cousin %s' % _("(spec file for SuSE 8.2)"),
+                  'David Coe %s' %_("(spec file cleanup)"),
+                  'David Petrou %s' % _("(testing and portability fixes for FreeBSD)"),
+                  'Han-Wen Nienhuys %s' % _("(the music font from Lilypond)"),
+                  'Jan Nieuwenhuizen %s' % _("(the music font from Lilypond)"),
                   ],
-                  ["Tom Cato Amundsen"],
+                  ["Tom Cato Amundsen", "Tom Eykens"],
                   trans, pixbuf)
             #self.g_about_window.connect('destroy', self.hide_about_window)
             #self.g_about_window.show()
