@@ -125,6 +125,12 @@ class Gui(abstract.IntervalGui):
             ])
         self.g_win.g_ui_manager.insert_action_group(self.g_action_group, 0)
         self.select_inputwidget()
+        def _f(watchvar):
+            self.on_end_practise()
+            self.on_start_practise()
+        for i in range(self.get_int('maximum_number_of_intervals')):
+            self.add_watch('ask_for_intervals_%i' % i, _f)
+        self.add_watch('number_of_intervals', _f)
     def run_test(self, *v):
         tw = intervaltest.MelodicIntervalTestDialog()
         tw.set_modal(True)
@@ -177,19 +183,24 @@ class Gui(abstract.IntervalGui):
             self.g_input.forget_last_tone()
             return
         self.m_answer.append(interval)
+        d = self.m_t.m_question[len(self.m_answer)-1]
+        d = d / abs(d)
         if not self.msg:
-            self.msg = utils.int_to_intervalname(interval, 1, 1)
+            self.msg = utils.int_to_intervalname(interval * d, 1, 1) + "+ ..."
         else:
-            self.msg = self.msg + "+" + utils.int_to_intervalname(interval, 1, 1)
-        self.g_flashbar.flash(self.msg)
+            self.msg = self.msg[:-4]
+            self.msg = self.msg + utils.int_to_intervalname(interval * d, 1, 1) + "+ ..."
+        self.g_flashbar.push(self.msg)
         if len(self.m_answer) == self.m_number_of_intervals_in_question:
             if self.m_t.guess_answer(self.m_answer,
                                      self.g_input.know_directions()):
+                self.g_flashbar.clear()
                 self.g_flashbar.flash(_("Correct"))
                 self.g_new_interval.set_sensitive(True)
                 self.g_new_interval.grab_focus()
                 self.g_give_up.set_sensitive(False)
             else:
+                self.g_flashbar.clear()
                 self.g_flashbar.flash(_("Wrong"))
                 if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                     self.m_t.play_question()
