@@ -32,6 +32,11 @@ import const
 import random
 import soundcard, cfg
 
+def mangle_email(email):
+    email = email.replace("@", " ,, ")
+    email = email.replace(".", " ,, ")
+    return email
+
 def play_tone(midi_int):
     soundcard.play_note(cfg.get_int('config/preferred_instrument'),
                         4, 0, midi_int,
@@ -148,6 +153,16 @@ def un_escape_url_string(s):
         return chr(eval("0x%s" % m.groups()[1]))
     return r.sub(f, s)
 
+def _str_to_dict(s):
+    D = {}
+    if s:
+        V = s.split(";")
+        for e in V:
+            n, v = e.split("=")
+            D[n.strip()] = v.strip()
+    for k in D:
+        D[k] = un_escape_url_string(D[k])
+    return D
 
 def parse_url(s):
     # protocol, action, fn, collection, lessonfile, config
@@ -160,17 +175,17 @@ def parse_url(s):
            (\?(?P<config>.*))? """, re.VERBOSE|re.DOTALL)
     m = r.match(s)
     if not m.group('protocol'):
-        if '#' in s:
-            return [None, None] + s.split('#', 1) + [None, None, {}]
+        if s.count('?') == 1:
+            page, config = s.split('?')
+        else:
+            page, config = s, None
+        if page.count("#") == 1:
+            page, anchor = page.split("#")
+        else:
+            anchor = None
+            return [None, None, page, anchor, None, None, _str_to_dict(config)]
         return None, None, s, None, None, None, {}
-    D = {}
-    if m.group('config'):
-        V = m.group('config').split(";")
-        for e in V:
-            n, v = e.split("=")
-            D[n.strip()] = v.strip()
-    for k in D:
-        D[k] = un_escape_url_string(D[k])
+    D = _str_to_dict(m.group('config'))
     return m.group('protocol'), m.group('action'), m.group('fn'), \
            m.group('anchor'), m.group('collection'), m.group('lessonfile'), D
 
@@ -252,3 +267,4 @@ if __name__ == '__main__':
     print parse_url("exercise:/main.html#23")
     print parse_url("solfege:practise/id-by-name/solfege/fifth-small-pure-0.99")
     print parse_url("solfege:/harmonic-interval?intervals=[1, 2, 3]")
+    print parse_url("../midi/Theory.html?SESSID=23423234")
